@@ -292,6 +292,22 @@ def delete(ctx, name: str, version: int, cluster: str) -> None:
         "This feature is only available to BYOC customers. "
     ),
 )
+@click.option(
+    "--hpd-preload",
+    "_fsx_preloading",
+    type=bool,
+    is_flag=True,
+    default=False,
+    help=(
+        "(beta) Use this flag when provisioning a high-performance datastore "
+        "when maximum performance is needed even on the first data access. (Due to "
+        "technical reasons HPDs without this flag achieve maximum performance after "
+        "the first data access). Avoid using this flag when the datastore needs to be "
+        "ready for use as soon as possible or when you're only working on a partition "
+        "of the data in the S3 bucket. \n\n"
+        "This feature is only available to BYOC customers. "
+    ),
+)
 @click.pass_context
 def create(
     ctx,
@@ -302,6 +318,7 @@ def create(
     _fsx_enabled: bool,
     _fsx_throughput_alias: str,
     _fsx_capacity_gib: int,
+    _fsx_preloading: bool,
     name: Optional[str] = None
 ) -> None:
     """Creates a datastore from SOURCE.
@@ -356,7 +373,8 @@ def create(
                     s3_no_copy=_no_copy_data_source,
                     fsx_enabled=_fsx_enabled,
                     fsx_throughput_alias=_fsx_throughput_alias,
-                    fsx_capacity_gib=_fsx_capacity_gib
+                    fsx_capacity_gib=_fsx_capacity_gib,
+                    fsx_preloading=_fsx_preloading,
                 )
                 click.echo(
                     f"\n{info.datastore_currently_creating_datastore(name=dstore.name, version=str(dstore.version), cluster=cluster)}"
@@ -371,7 +389,8 @@ def create(
                     s3_no_copy=_no_copy_data_source,
                     fsx_enabled=_fsx_enabled,
                     fsx_throughput_alias=_fsx_throughput_alias,
-                    fsx_capacity_gib=_fsx_capacity_gib
+                    fsx_capacity_gib=_fsx_capacity_gib,
+                    fsx_preloading=_fsx_preloading,
                 )
                 click.echo(
                     f"\n{info.datastore_currently_creating_datastore(name=dstore.name, version=str(dstore.version), cluster=cluster)}"
