@@ -7,6 +7,9 @@ import click
 import rich
 from rich import box
 from rich.console import Console, RenderableType
+from rich.rule import Rule
+from rich.style import Style
+
 try:
     from rich.console import RenderGroup
 except ImportError:
@@ -44,6 +47,7 @@ GRID_THEME = Theme(
         "argument": GridColors.TEAL,
         "option": GridColors.ORANGE,
         "command": GridColors.TEAL,
+        "maintenance": GridColors.GREEN,
     },
     inherit=False,
 )
@@ -73,6 +77,18 @@ def render(renderable: RenderableType):
     return capture.get()
 
 
+def render_maintenance_window(renderable: RenderableType):
+    """Utility method to render a ``rich.RenderableType`` alongside a 'Maintenance Window' header."""
+    msg = render(
+        RenderGroup(
+            Rule("[bold]NOTICE", style=Style(color=GridColors.GREEN, bold=True)),
+            '[maintenance]Upcoming Maintenance[/maintenance]:', pad(renderable),
+            Rule(style=Style(color=GridColors.GREEN, bold=True))
+        )
+    )
+    return msg
+
+
 def render_warning(renderable: RenderableType):
     """Utility method to render a ``rich.RenderableType`` alongside a 'Warning' header."""
     return render(RenderGroup(
@@ -339,6 +355,14 @@ def main_group(name=None, cls=None, **attrs):
                 )
 
         def parse_args(self, ctx, args):
+            # NOTE: Uncomment lines bellow and replace timestamp to print maintenance window message
+            #       before every command is run (when a maintenance window / downtime is scheduled)
+            # message = render_maintenance_window(
+            #     "Grid will be unavailable on Sunday May 29, 2022 from 9pm-11pm EST. \n"
+            #     "Please ensure you have no active Runs, Sessions, or Experiments.",
+            # )
+            # click.echo(message)
+
             if not is_latest_version():
                 message = render_warning(
                     f"A newer version of [command_path]{__package_name__}[/command_path] is available. To upgrade, "
