@@ -151,6 +151,7 @@ class Datastore:
     _fsx_enabled: bool
     _fsx_throughput_mbs_tib: int
     _fsx_capacity_gib: int
+    _fsx_preloading: bool
 
     _is_deleted: bool
     _is_created: bool
@@ -167,6 +168,7 @@ class Datastore:
         fsx_enabled: bool = False,
         fsx_throughput_alias="low",
         fsx_capacity_gib=1200,
+        fsx_preloading=False,
     ):
         """Initialize a new DataStore Object.
 
@@ -204,6 +206,8 @@ class Datastore:
             Which throughput tier to provision for the FSx file system. low=125mb/s/tib, medium=500mb/s/tib, high=1000mb/s/tib
         fsx_capacity_gib
             How much capacity to provision for the FSx file system, must be 1200, 2400 or a multiple of 2400
+        fsx_preloading
+            Whether to preload the data to the FSx file system on datastore creation
         """
         # --------------------------------------------------------------------------- #
         #    This should be the first block that goes into the constructor of the     #
@@ -256,6 +260,7 @@ class Datastore:
 
         self._fsx_throughput_mbs_tib = 0
         self._fsx_capacity_gib = 0
+        self._fsx_preloading = False
 
         if fsx_enabled is True:
             if fsx_throughput_alias not in DATASTORE_FSX_THROUGHPUT_ALIASES:
@@ -266,6 +271,7 @@ class Datastore:
             else:
                 self._fsx_throughput_mbs_tib = DATASTORE_FSX_THROUGHPUT_ALIASES[fsx_throughput_alias]
                 self._fsx_capacity_gib = fsx_capacity_gib
+                self._fsx_preloading = fsx_preloading
 
         self._name = name
         self._version = 0
@@ -512,7 +518,8 @@ class Datastore:
             no_copy_data_source=self._s3_no_copy,
             fsx_enabled=self._fsx_enabled,
             fsx_throughput_mbs_tib=self._fsx_throughput_mbs_tib,
-            fsx_capacity_gib=self._fsx_capacity_gib
+            fsx_capacity_gib=self._fsx_capacity_gib,
+            fsx_preloading=self._fsx_preloading,
         )
 
         self._id = dstore.id
