@@ -1,18 +1,12 @@
 from grid.openapi import (
     ApiClient, AuthServiceApi, ClusterServiceApi, DatastoreServiceApi, RunServiceApi, SAMLOrganizationsServiceApi,
-    SessionServiceApi, TensorboardServiceApi, ExperimentServiceApi
+    SessionServiceApi, TensorboardServiceApi, ExperimentServiceApi, CredentialServiceApi
 )
 
 
 class GridRestClient(
-    AuthServiceApi,
-    ClusterServiceApi,
-    DatastoreServiceApi,
-    RunServiceApi,
-    SAMLOrganizationsServiceApi,
-    SessionServiceApi,
-    TensorboardServiceApi,
-    ExperimentServiceApi,
+    AuthServiceApi, ClusterServiceApi, DatastoreServiceApi, RunServiceApi, SAMLOrganizationsServiceApi,
+    SessionServiceApi, TensorboardServiceApi, ExperimentServiceApi, CredentialServiceApi
 ):
     api_client: ApiClient
 
