@@ -933,7 +933,7 @@ class Run:
                 yield artifact
 
 
-def list_runs(cluster_id: Optional[str] = None, is_global: bool = False) -> List[Run]:
+def list_runs(cluster_id: Optional[str] = None, is_global: bool = False, query: str = None) -> List[Run]:
     """
     List all runs on the cluster with the provided cluster id
 
@@ -944,6 +944,8 @@ def list_runs(cluster_id: Optional[str] = None, is_global: bool = False) -> List
         in settings.json) is used.
     is_global:
         If True, return runs of all users in the team
+	name:
+		if specified, will filter by run name startswith
     """
     cluster_id = cluster_id or env.CONTEXT
     client = GridRestClient(api_client=create_swagger_client())
@@ -955,7 +957,7 @@ def list_runs(cluster_id: Optional[str] = None, is_global: bool = False) -> List
             for user_details in team.data.get("members", {}):
                 users[user_details["id"]] = user_details
     all_runs = []
-    for run_resp in rest_list_runs(client=client, cluster_id=cluster_id, user_ids=list(users.keys())):
+    for run_resp in rest_list_runs(client=client, cluster_id=cluster_id, user_ids=list(users.keys()), query=query):
         run_obj = Run(name=SPECIAL_NAME_TO_SKIP_OBJECT_INIT)
         fill_object_from_response(run_obj, run_resp)
         user_details = users.get(run_obj.user.user_id, {})
