@@ -23,6 +23,8 @@ from rich.progress import Progress, TextColumn, BarColumn, DownloadColumn, TaskI
 from rich.status import Status
 from urllib3 import Retry
 
+from grid.sdk.user_messaging import errors
+
 try:
     from rich.console import RenderGroup as Group
 except ImportError:
@@ -62,11 +64,12 @@ def handle_termination_signal(signum, frame):
 
 
 def wrap_signals(fn):
-    global received_signal
-    prev_sigint_handler = signal.signal(signal.SIGINT, handle_termination_signal)
-    prev_sigterm_handler = signal.signal(signal.SIGTERM, handle_termination_signal)
-
     def wrapper(*args, **kwargs):
+
+        global received_signal
+        prev_sigint_handler = signal.signal(signal.SIGINT, handle_termination_signal)
+        prev_sigterm_handler = signal.signal(signal.SIGTERM, handle_termination_signal)
+
         try:
             fn(*args, **kwargs)
         except RuntimeError as e:
@@ -499,7 +502,7 @@ def _upload_next_batch(c: 'GridRestClient', work: Work, progress_bar: PBar) -> D
 
         for future in concurrent.futures.as_completed(futures):
             if done_event.is_set():
-                raise RuntimeError("Termination signal (ie. SIGINT, SIGTERM, or SIGKILL) received")
+                raise RuntimeError(errors.datastore_upload_process_cancelled())
             res = future.result()
             uploaded_file_tasks[res.data_file_local_id].append(res)
 
@@ -522,14 +525,14 @@ def _start_upload(c: 'GridRestClient', grid_dir: Path, work: Work, progress_bar:
     while True:
         if done_event.is_set():
             # stop progression since we're in trouble.
-            raise RuntimeError("Termination signal (ie. SIGINT, SIGTERM, or SIGKILL) received")
+            raise RuntimeError(errors.datastore_upload_process_cancelled())
 
         progress_bar.action_status.update(progress_bar.status_text_uploading)
 
         completed_files = _upload_next_batch(c=c, work=work, progress_bar=progress_bar)
         if done_event.is_set():
             # don't save if we're not sure that everything completed uploading.
-            raise RuntimeError("Termination signal (ie. SIGINT, SIGTERM, or SIGKILL) received")
+            raise RuntimeError(errors.datastore_upload_process_cancelled())
 
         if len(completed_files) == 0:
             break
@@ -567,7 +570,7 @@ def _start_finalize(c: 'GridRestClient', grid_dir: Path, work: Work, progress_ba
 
     while True:
         if done_event.is_set():
-            raise RuntimeError("Termination signal (ie. SIGINT, SIGTERM, or SIGKILL) received")
+            raise RuntimeError(errors.datastore_upload_process_cancelled())
 
         progress_bar.action_status.update(progress_bar.status_text_finalizing)
         completed_batch = _get_next_finalize_batch(work)
